@@ -1,5 +1,10 @@
-use crate::color::*;
-use crate::styled_char::StyledChar;
+use {
+    crate::{
+        color::*,
+        styled_char::StyledChar,
+    },
+    crossterm::style::Color,
+};
 
 /// A scrollbar style defined by two styled chars, one
 ///  for the track, and one for the thumb.
@@ -20,6 +25,10 @@ impl ScrollBarStyle {
             thumb: StyledChar::from_fg_char(gray(21), char),
         }
     }
+    pub fn set_bg(&mut self, bg: Color) {
+        self.track.set_bg(bg);
+        self.thumb.set_bg(bg);
+    }
 }
 
 impl Default for ScrollBarStyle {
